==> oci-java-sdk-shaded-full-3.40.0-sources.jar: com/oracle/bmc/cloudbridge/model/AssetSourceCredentials.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.cloudbridge.model;

/**
 * Credentials for an asset source. <br>
 * Note: Objects should always be created or deserialized using the {@link Builder}. This model
 * distinguishes fields that are {@code null} because they are unset from fields that are explicitly
 * set to {@code null}. This is done in the setter methods of the {@link Builder}, which maintain a
 * set of all explicitly set fields called {@link Builder#__explicitlySet__}. The {@link
 * #hashCode()} and {@link #equals(Object)} methods are implemented to take the explicitly set
 * fields into account. The constructor, on the other hand, does not take the explicitly set fields
 * into account (since the constructor cannot distinguish explicit {@code null} from unset {@code
 * null}).
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20220509")
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(
        builder = AssetSourceCredentials.Builder.class)
@com.fasterxml.jackson.annotation.JsonFilter(
        com.oracle.bmc.http.client.internal.ExplicitlySetBmcModel.EXPLICITLY_SET_FILTER_NAME)
public final class AssetSourceCredentials
        extends com.oracle.bmc.http.client.internal.ExplicitlySetBmcModel {
    @Deprecated
    @java.beans.ConstructorProperties({"type", "secretId"})
    public AssetSourceCredentials(AssetSourceCredentialsType type, String secretId) {
        super();
        this.type = type;
        this.secretId = secretId;
    }

    @com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder(withPrefix = "")
    public static class Builder {
        /** Authentication type */
        @com.fasterxml.jackson.annotation.JsonProperty("type")
        private AssetSourceCredentialsType type;

        /**
         * Authentication type
         *
         * @param type the value to set
         * @return this builder
         */
        public Builder type(AssetSourceCredentialsType type) {
            this.type = type;
            this.__explicitlySet__.add("type");
            return this;
        }
        /**
         * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the
         * secret in a vault. If the the type of the credentials is BASIC{@code , the secret must
         * contain the username and password in JSON format, which is in the form of }{ "username":
         * "<VMwareUser>", "password": "<VMwarePassword>" }.
         */
        @com.fasterxml.jackson.annotation.JsonProperty("secretId")
        private String secretId;

        /**
         * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the
         * secret in a vault. If the the type of the credentials is BASIC{@code , the secret must
         * contain the username and password in JSON format, which is in the form of }{ "username":
         * "<VMwareUser>", "password": "<VMwarePassword>" }.
         *
         * @param secretId the value to set
         * @return this builder
         */
        public Builder secretId(String secretId) {
            this.secretId = secretId;
            this.__explicitlySet__.add("secretId");
            return this;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        private final java.util.Set<String> __explicitlySet__ = new java.util.HashSet<String>();

        public AssetSourceCredentials build() {
            AssetSourceCredentials model = new AssetSourceCredentials(this.type, this.secretId);
            for (String explicitlySetProperty : this.__explicitlySet__) {
                model.markPropertyAsExplicitlySet(explicitlySetProperty);
            }
            return model;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        public Builder copy(AssetSourceCredentials model) {
            if (model.wasPropertyExplicitlySet("type")) {
                this.type(model.getType());
            }
            if (model.wasPropertyExplicitlySet("secretId")) {
                this.secretId(model.getSecretId());
            }
            return this;
        }
    }

    /** Create a new builder. */
    public static Builder builder() {
        return new Builder();
    }

    public Builder toBuilder() {
        return new Builder().copy(this);
    }

    /** Authentication type */
    @com.fasterxml.jackson.annotation.JsonProperty("type")
    private final AssetSourceCredentialsType type;

    /**
     * Authentication type
     *
     * @return the value
     */
    public AssetSourceCredentialsType getType() {
        return type;
    }

    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the
     * secret in a vault. If the the type of the credentials is BASIC{@code , the secret must
     * contain the username and password in JSON format, which is in the form of }{ "username":
     * "<VMwareUser>", "password": "<VMwarePassword>" }.
     */
    @com.fasterxml.jackson.annotation.JsonProperty("secretId")
    private final String secretId;

    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the
     * secret in a vault. If the the type of the credentials is BASIC{@code , the secret must
     * contain the username and password in JSON format, which is in the form of }{ "username":
     * "<VMwareUser>", "password": "<VMwarePassword>" }.
     *
     * @return the value
     */
    public String getSecretId() {
        return secretId;
    }

    @Override
    public String toString() {
        return this.toString(true);
    }

    /**
     * Return a string representation of the object.
     *
     * @param includeByteArrayContents true to include the full contents of byte arrays
     * @return string representation
     */
    public String toString(boolean includeByteArrayContents) {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("AssetSourceCredentials(");
        sb.append("super=").append(super.toString());
        sb.append("type=").append(String.valueOf(this.type));
        sb.append(", secretId=").append(String.valueOf(this.secretId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof AssetSourceCredentials)) {
            return false;
        }

        AssetSourceCredentials other = (AssetSourceCredentials) o;
        return java.util.Objects.equals(this.type, other.type)
                && java.util.Objects.equals(this.secretId, other.secretId)
                && super.equals(other);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = 1;
        result = (result * PRIME) + (this.type == null ? 43 : this.type.hashCode());
        result = (result * PRIME) + (this.secretId == null ? 43 : this.secretId.hashCode());
        result = (result * PRIME) + super.hashCode();
        return result;
    }
}

==> oci-java-sdk-shaded-full-3.63.1-sources.jar: com/oracle/bmc/cloudbridge/model/AssetSourceCredentials.java <==
/**
 * Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.cloudbridge.model;

/**
 * Credentials for an asset source. <br>
 * Note: Objects should always be created or deserialized using the {@link Builder}. This model
 * distinguishes fields that are {@code null} because they are unset from fields that are explicitly
 * set to {@code null}. This is done in the setter methods of the {@link Builder}, which maintain a
 * set of all explicitly set fields called {@link Builder#__explicitlySet__}. The {@link
 * #hashCode()} and {@link #equals(Object)} methods are implemented to take the explicitly set
 * fields into account. The constructor, on the other hand, does not take the explicitly set fields
 * into account (since the constructor cannot distinguish explicit {@code null} from unset {@code
 * null}).
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20220509")
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(
        builder = AssetSourceCredentials.Builder.class)
@com.fasterxml.jackson.annotation.JsonFilter(
        com.oracle.bmc.http.client.internal.ExplicitlySetBmcModel.EXPLICITLY_SET_FILTER_NAME)
public final class AssetSourceCredentials
        extends com.oracle.bmc.http.client.internal.ExplicitlySetBmcModel {
    @Deprecated
    @java.beans.ConstructorProperties({"type", "secretId"})
    public AssetSourceCredentials(AssetSourceCredentialsType type, String secretId) {
        super();
        this.type = type;
        this.secretId = secretId;
    }

    @com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder(withPrefix = "")
    public static class Builder {
        /** Authentication type */
        @com.fasterxml.jackson.annotation.JsonProperty("type")
        private AssetSourceCredentialsType type;

        /**
         * Authentication type
         *
         * @param type the value to set
         * @return this builder
         */
        public Builder type(AssetSourceCredentialsType type) {
            this.type = type;
            this.__explicitlySet__.add("type");
            return this;
        }
        /**
         * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the
         * secret in a vault. If the type of the credentials is {@code BASIC}, the secret must
         * contain the username and password in JSON format, which is in the form of {@code {
         * "username": "<User>", "password": "example-password" }}. If the type of the credentials
         * is {@code API_KEY}, the secret must contain the accessKeyId and secretAccessKey in JSON
         * format, which is in the form of {@code { "accessKeyId": "<AccessKey>", "secretAccessKey":
         * "<AccessKeyValue>" }}.
         */
        @com.fasterxml.jackson.annotation.JsonProperty("secretId")
        private String secretId;

        /**
         * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the
         * secret in a vault. If the type of the credentials is {@code BASIC}, the secret must
         * contain the username and password in JSON format, which is in the form of {@code {
         * "username": "<User>", "password": "example-password" }}. If the type of the credentials
         * is {@code API_KEY}, the secret must contain the accessKeyId and secretAccessKey in JSON
         * format, which is in the form of {@code { "accessKeyId": "<AccessKey>", "secretAccessKey":
         * "<AccessKeyValue>" }}.
         *
         * @param secretId the value to set
         * @return this builder
         */
        public Builder secretId(String secretId) {
            this.secretId = secretId;
            this.__explicitlySet__.add("secretId");
            return this;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        private final java.util.Set<String> __explicitlySet__ = new java.util.HashSet<String>();

        public AssetSourceCredentials build() {
            AssetSourceCredentials model = new AssetSourceCredentials(this.type, this.secretId);
            for (String explicitlySetProperty : this.__explicitlySet__) {
                model.markPropertyAsExplicitlySet(explicitlySetProperty);
            }
            return model;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        public Builder copy(AssetSourceCredentials model) {
            if (model.wasPropertyExplicitlySet("type")) {
                this.type(model.getType());
            }
            if (model.wasPropertyExplicitlySet("secretId")) {
                this.secretId(model.getSecretId());
            }
            return this;
        }
    }

    /** Create a new builder. */
    public static Builder builder() {
        return new Builder();
    }

    public Builder toBuilder() {
        return new Builder().copy(this);
    }

    /** Authentication type */
    @com.fasterxml.jackson.annotation.JsonProperty("type")
    private final AssetSourceCredentialsType type;

    /**
     * Authentication type
     *
     * @return the value
     */
    public AssetSourceCredentialsType getType() {
        return type;
    }

    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the
     * secret in a vault. If the type of the credentials is {@code BASIC}, the secret must contain
     * the username and password in JSON format, which is in the form of {@code { "username":
     * "<User>", "password": "example-password" }}. If the type of the credentials is {@code
     * API_KEY}, the secret must contain the accessKeyId and secretAccessKey in JSON format, which
     * is in the form of {@code { "accessKeyId": "<AccessKey>", "secretAccessKey":
     * "<AccessKeyValue>" }}.
     */
    @com.fasterxml.jackson.annotation.JsonProperty("secretId")
    private final String secretId;

    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the
     * secret in a vault. If the type of the credentials is {@code BASIC}, the secret must contain
     * the username and password in JSON format, which is in the form of {@code { "username":
     * "<User>", "password": "example-password" }}. If the type of the credentials is {@code
     * API_KEY}, the secret must contain the accessKeyId and secretAccessKey in JSON format, which
     * is in the form of {@code { "accessKeyId": "<AccessKey>", "secretAccessKey":
     * "<AccessKeyValue>" }}.
     *
     * @return the value
     */
    public String getSecretId() {
        return secretId;
    }

    @Override
    public String toString() {
        return this.toString(true);
    }

    /**
     * Return a string representation of the object.
     *
     * @param includeByteArrayContents true to include the full contents of byte arrays
     * @return string representation
     */
    public String toString(boolean includeByteArrayContents) {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("AssetSourceCredentials(");
        sb.append("super=").append(super.toString());
        sb.append("type=").append(String.valueOf(this.type));
        sb.append(", secretId=").append(String.valueOf(this.secretId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof AssetSourceCredentials)) {
            return false;
        }

        AssetSourceCredentials other = (AssetSourceCredentials) o;
        return java.util.Objects.equals(this.type, other.type)
                && java.util.Objects.equals(this.secretId, other.secretId)
                && super.equals(other);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = 1;
        result = (result * PRIME) + (this.type == null ? 43 : this.type.hashCode());
        result = (result * PRIME) + (this.secretId == null ? 43 : this.secretId.hashCode());
        result = (result * PRIME) + super.hashCode();
        return result;
    }
}
